@@ -3,6 +3,7 @@
 
 import sys
 import os
+import time
 import errno
 import signal
 import atexit
@@ -10,6 +11,7 @@ import __main__
 
 from application import log
 from application.python.types import Singleton
+from application.system import host
 
 
 __all__ = 'Process', 'ProcessError', 'Signals', 'process'
@@ -32,26 +34,28 @@ class Process(object):
         self._system_config_directory = '/etc'
         self._local_config_directory = os.path.dirname(os.path.realpath(getattr(__main__, '__file__', sys.executable if hasattr(sys, 'frozen') else 'none')))
 
-    def _get_local_config_directory(self):
+    @property
+    def local_config_directory(self):
         return self._local_config_directory
 
-    def _set_local_config_directory(self, path):
+    @local_config_directory.setter
+    def local_config_directory(self, path):
         self._local_config_directory = os.path.realpath(path)
 
-    local_config_directory = property(_get_local_config_directory, _set_local_config_directory)
-
-    def _get_system_config_directory(self):
+    @property
+    def system_config_directory(self):
         return self._system_config_directory
 
-    def _set_system_config_directory(self, path):
+    @system_config_directory.setter
+    def system_config_directory(self, path):
         self._system_config_directory = os.path.realpath(path)
 
-    system_config_directory = property(_get_system_config_directory, _set_system_config_directory)
-
-    def _get_runtime_directory(self):
+    @property
+    def runtime_directory(self):
         return self._runtime_directory
 
-    def _set_runtime_directory(self, path):
+    @runtime_directory.setter
+    def runtime_directory(self, path):
         path = os.path.realpath(path)
         if not os.path.isdir(path):
             try:
@@ -62,8 +66,6 @@ class Process(object):
             raise ProcessError("runtime directory %s is not writable" % path)
         self._runtime_directory = path
 
-    runtime_directory = property(_get_runtime_directory, _set_runtime_directory)
-
     def _check_if_running(self):
         """Check if the process is already running"""
         pidfile = self._pidfile
@@ -218,6 +220,25 @@ class Process(object):
         else:
             return os.path.realpath(name)
 
+    @staticmethod
+    def wait_for_network(wait_time=10, wait_message=None, test_ip='1.2.3.4'):
+        """
+        Make sure the network is available and can be reached. The function
+        will return as soon as the network is reachable or it will raise
+        RuntimeError if network is still unreachable after wait_time. The
+        default value for test_ip checks if internet is reachable. Optionally
+        it can log wait_message at INFO level if the function needs to wait.
+        """
+        for step in range(wait_time):
+            local_ip = host.outgoing_ip_for(test_ip)
+            if local_ip is not None:
+                break
+            elif step == 0 and wait_message is not None:
+                log.info(wait_message)
+            time.sleep(1)
+        else:
+            raise RuntimeError('Network is not available after waiting for {} seconds'.format(wait_time))
+
 
 class Signals(object):
     """Interface to the system signals"""
